MethodChannelDeviceInfo class

An implementation of DeviceInfoPlatform that uses method channels.

Inheritance

Constructors

MethodChannelDeviceInfo()

Properties

channel ↔ MethodChannel
The method channel used to interact with the native platform.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

androidInfo() → Future<AndroidDeviceInfo>
Gets the Android device information.
override
iosInfo() → Future<IosDeviceInfo>
Gets the iOS device information.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited